.. _installation:

Installation
------------


Python packages
'''''''''''''''

Pylint should be easily installable using pip.

.. code-block:: sh

   pip install pylint


Source distribution installation
''''''''''''''''''''''''''''''''

From the source distribution, extract the tarball, go to the extracted
directory and simply run ::

    python setup.py install

Or you can install it in editable mode, using ::

    python setup.py develop
